@@ -13,11 +13,7 @@ class Feed(MutableSequence[Entry]):
 
     def __attrs_post_init__(self) -> None:
         if isinstance(self.channel, dict):
-            self.channel = Channel(
-                title=self.channel["title"],
-                link=self.channel["link"],
-                description=self.channel["description"],
-            )
+            self.channel = Channel.from_dict(self.channel)
         elif isinstance(self.channel, Channel):
             pass
         else:
@@ -26,14 +22,7 @@ class Feed(MutableSequence[Entry]):
         items: List[Entry] = list()
         for item in self.items:
             if isinstance(item, dict):
-                items.append(
-                    Entry(
-                        title=item["title"],
-                        link=item["link"],
-                        description=item["description"],
-                        author=item["author"],
-                    )
-                )
+                items.append(Entry.from_dict(item))
             elif isinstance(item, Entry):
                 items.append(item)
             else:
